@@ -81,7 +81,7 @@ PyDoc_STRVAR(module_doc,
   bit2_to_bit2compl(TYPENAME ## _AS_STRING(bit2_a), n_bit2,		\
 		    TYPENAME ## _AS_STRING(bit2_rca));			\
   bit2_to_bit2rev(TYPENAME ## _AS_STRING(bit2_rca), n_bit2,		\
-		  TYPENAME ## _AS_STRING(bit2_rca));			\  
+		  TYPENAME ## _AS_STRING(bit2_rca));			\
   return bit2_rca;							\
 
 
@@ -226,14 +226,13 @@ static inline void bit2_to_bit2compl(const char *bit2_ptr,
 				     const Py_ssize_t bit2_n,
 				     char *bit2compl_prt)
 {
-  Py_ssize_t dna_i, bit2_i;
+  Py_ssize_t bit2_i;
   unsigned char cur_byte;
 
   #ifdef LIBDNA_DEBUG
   printf("bit2_n: %zd\n", bit2_n);
   #endif
 
-  dna_i = 0;
   for (bit2_i=0; bit2_i < bit2_n; bit2_i++)
     {
       cur_byte = bit2_ptr[bit2_i];
@@ -270,7 +269,7 @@ static inline void bit2_to_bit2rev(const char *bit2_ptr,
 				   const Py_ssize_t bit2_n,
 				   char *bit2rev_prt)
 {
-  Py_ssize_t dna_i, bit2_i;
+  Py_ssize_t bit2_i;
   unsigned char lcur_byte, rcur_byte;
   int bitpos;
 
@@ -623,7 +622,8 @@ PyInit__libdna(void)
          * object; doing it here is required for portability to Windows 
          * without requiring C++. */
 
-  PyObject *m, *d;
+  PyObject *m;
+  /* *d; */
   //  static void *PyRinterface_API[PyRinterface_API_pointers];
   //PyObject *c_api_object;
 
