@@ -39,6 +39,9 @@ class FastaFile(file):
         wrap = io.OpenWrapper(self.fileno(), closefd = False)
         return read_fasta(wrap)
 
+class FastabError(ValueError):
+    pass
+
 class FastabFile(file):
     """ FASTAB file.
     The default iterator will go through the entries in the file (not the rows).
@@ -138,10 +141,15 @@ def tofastab(fasta, stream, force_upper = True):
     #print("%i %i" % (len(vec), len(header)))
 
 
-def read_fastab(stream):
+def read_fastab(stream, maxhead = 500, maxseq = 100000):
     """
     Load a FASTA 'EntryBin' from a binary stream.
 
+    - maxhead: maximum number of bytes for the head. If the header
+    goes beyond it, an exception FastabError is raised.
+    - maxseq: maximum number of bytes for the head. If the header
+    goes beyond it, an exception FastabError is raised.
+
     The format is as follows:
 
     - size of the sequence: 8 bytes as an unsigned long long
@@ -162,6 +170,11 @@ def read_fastab(stream):
             else:
                 raise FastaError("Truncated FASTAB file (incomplete entry descriptor).")
         nseq, nhead = struct.unpack('<QH', raw)
+        if nhead > maxhead:
+            raise FastabError("Header size over the limit (%i > %i)" % (nhead, maxhead))
+        if nseq > maxseq:
+            raise FastabError("Sequence size over the limit (%i > %i)" % (nhead, maxhead))
+
         raw = stream.read(nhead)
         
         if len(raw) < nhead:
